==> jc-1.4.0.tar.gz: soot/jimple/parser/node/XPDeclaration.h <==
// public abstract class soot.jimple.parser.node.XPDeclaration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b78912b2d6bd2ea8 soot_jimple_parser_node_XPDeclaration

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_XPDeclaration_H_
#define _JC_soot_jimple_parser_node_XPDeclaration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	_jc_soot_jimple_parser_node_XPDeclaration$sub_refs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	_jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$refs	_jc_soot_jimple_parser_node_XPDeclaration$refs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$nonrefs	_jc_soot_jimple_parser_node_XPDeclaration$nonrefs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$object	_jc_soot_jimple_parser_node_XPDeclaration$object;

typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vmethods	_jc_soot_jimple_parser_node_XPDeclaration$vmethods;
typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vtable	_jc_soot_jimple_parser_node_XPDeclaration$vtable;
typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vtype	_jc_soot_jimple_parser_node_XPDeclaration$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_XPDeclaration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_XPDeclaration$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_node_XPDeclaration$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_XPDeclaration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPDeclaration$vmethods	soot_jimple_parser_node_XPDeclaration;
};

// Vtype
struct _jc_soot_jimple_parser_node_XPDeclaration$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_XPDeclaration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_XPDeclaration$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_XPDeclaration$refs {
    _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_XPDeclaration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	soot_jimple_parser_node_XPDeclaration;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_XPDeclaration$object {
	_jc_soot_jimple_parser_node_XPDeclaration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_XPDeclaration$vtype	*vtype;
	_jc_soot_jimple_parser_node_XPDeclaration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_XPDeclaration$vtype _jc_soot_jimple_parser_node_XPDeclaration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_XPDeclaration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_XPDeclaration$class_object;

#endif	/* _JC_soot_jimple_parser_node_XPDeclaration_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/XPDeclaration.h <==
// public abstract class soot.jimple.parser.node.XPDeclaration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b78912b2d6bd2ea8 soot_jimple_parser_node_XPDeclaration

// header file dependencies
// @dep_header soot_jimple_parser_node_Node

#include "soot/jimple/parser/node/Node.h"

#ifndef _JC_soot_jimple_parser_node_XPDeclaration_H_
#define _JC_soot_jimple_parser_node_XPDeclaration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	_jc_soot_jimple_parser_node_XPDeclaration$sub_refs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	_jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$refs	_jc_soot_jimple_parser_node_XPDeclaration$refs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$nonrefs	_jc_soot_jimple_parser_node_XPDeclaration$nonrefs;
typedef struct _jc_soot_jimple_parser_node_XPDeclaration$object	_jc_soot_jimple_parser_node_XPDeclaration$object;

typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vmethods	_jc_soot_jimple_parser_node_XPDeclaration$vmethods;
typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vtable	_jc_soot_jimple_parser_node_XPDeclaration$vtable;
typedef const struct _jc_soot_jimple_parser_node_XPDeclaration$vtype	_jc_soot_jimple_parser_node_XPDeclaration$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_XPDeclaration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_XPDeclaration$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_XPDeclaration$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_node_XPDeclaration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPDeclaration$vmethods	soot_jimple_parser_node_XPDeclaration;
};

// Vtype
struct _jc_soot_jimple_parser_node_XPDeclaration$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_XPDeclaration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_XPDeclaration$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_XPDeclaration$refs {
    _jc_soot_jimple_parser_node_XPDeclaration$sub_refs	soot_jimple_parser_node_XPDeclaration;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_XPDeclaration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPDeclaration$sub_nonrefs	soot_jimple_parser_node_XPDeclaration;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_XPDeclaration$object {
	_jc_soot_jimple_parser_node_XPDeclaration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_XPDeclaration$vtype	*vtype;
	_jc_soot_jimple_parser_node_XPDeclaration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_XPDeclaration$vtype _jc_soot_jimple_parser_node_XPDeclaration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_XPDeclaration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_XPDeclaration$class_object;

#endif	/* _JC_soot_jimple_parser_node_XPDeclaration_H_ */
